@@ -1,10 +1,10 @@
 <?php
 /*
-$Id: edit.php 5451 2014-10-01 18:42:27Z gruberroland $
+$Id: edit.php 5519 2015-02-16 19:54:21Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Tilo Lutz
-                2005 - 2014  Roland Gruber
+                2005 - 2015  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ include_once('../../lib/modules.inc');
 startSecureSession();
 
 // Redirect to startpage if user is not loged in
-if (!isset($_SESSION['loggedIn']) || ($_SESSION['loggedIn'] !== true)) {
+if (!isLoggedIn()) {
 	metaRefresh("../login.php");
 	exit;
 	}
@@ -57,6 +57,7 @@ if (!isset($_SESSION['loggedIn']) || ($_SESSION['loggedIn'] !== true)) {
 // Set correct language, codepages, ....
 setlanguage();
 
+
 //load account
 if (isset($_GET['DN'])) {
 	$DN = str_replace("\\'", '', $_GET['DN']);
@@ -80,7 +81,7 @@ if (isset($_GET['DN'])) {
 		logNewMessage(LOG_ERR, 'User tried to access entry of type ' . $type . ' outside suffix ' . $suffix);
 		die();
 	}
-	$_SESSION['account'] = new accountContainer($type, 'account');
+	$_SESSION['account'] = new accountContainer($type, 'account', getRandomNumber());
 	$result = $_SESSION['account']->load_account($DN);
 	if (sizeof($result) > 0) {
 		include '../main_header.php';
@@ -103,7 +104,7 @@ else if (count($_POST)==0) {
 		logNewMessage(LOG_ERR, 'User tried to create entry of forbidden account type: ' . $type);
 		die();
 	}
-	$_SESSION['account'] = new accountContainer($type, 'account');
+	$_SESSION['account'] = new accountContainer($type, 'account', getRandomNumber());
 	$_SESSION['account']->new_account();
 }
 
