@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: mainlogin.php 5317 2014-03-29 11:04:14Z gruberroland $
+$Id: mainlogin.php 5667 2015-08-02 19:16:46Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2014  Roland Gruber
+  Copyright (C) 2003 - 2015  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ echo $_SESSION['header'];
 				echo _("Login");
 			?>
 		</title>
-	<?php 
+	<?php
 		// include all CSS files
 		$cssDirName = dirname(__FILE__) . '/../../style';
 		$cssDir = dir($cssDirName);
@@ -137,7 +137,7 @@ echo $_SESSION['header'];
 		<form action="mainlogin.php" method="post" autocomplete="off">
 		<table align="center">
 		<tr><td>
-		<table align="center" border="2" rules="none" bgcolor="white" class="ui-corner-all" style="padding: 20px;">
+		<table align="center" border="0" rules="none" bgcolor="white" class="ui-corner-all roundedShadowBox" style="padding: 20px;">
 		<tr><td>
 		<?php
 		$spacer = new htmlSpacer('20px', '20px');
@@ -166,8 +166,8 @@ echo $_SESSION['header'];
 		$passwordGroup->addElement($gap);
 		$passwordGroup->addElement(new htmlHelpLink('236'));
 		$table->addElement($passwordGroup, true);
-		
-		
+
+
 		$tabindex = 1;
 		parseHtml(null, $table, array(), false, $tabindex, 'user');
 		?>
