@@ -1,6 +1,6 @@
 /**
 
-$Id: 500_lam.js 5477 2014-11-10 20:51:04Z gruberroland $
+$Id: 500_lam.js 5606 2015-06-16 18:59:56Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2014  Roland Gruber
@@ -208,14 +208,16 @@ function profileShowDeleteDialog(title, okText, cancelText, scope, selectFieldNa
  * Shows a simple dialog.
  * 
  * @param title dialog title
- * @param okText text for Ok button
+ * @param okText text for Ok button (optional, submits form)
  * @param cancelText text for Cancel button
  * @param formID form ID
  * @param dialogDivID ID of div that contains dialog content
  */
 function showSimpleDialog(title, okText, cancelText, formID, dialogDivID) {
 	var buttonList = {};
-	buttonList[okText] = function() { document.forms[formID].submit(); };
+	if (okText) {
+		buttonList[okText] = function() { document.forms[formID].submit(); };
+	}
 	buttonList[cancelText] = function() { jQuery(this).dialog("close"); };
 	jQuery('#' + dialogDivID).dialog({
 		modal: true,
@@ -324,11 +326,7 @@ function showConfirmationDialog(title, okText, cancelText, dialogDiv, formName,
 		if (resultField) {
 			jQuery('#' + resultField).val('ok');
 		};
-		var inputs = jQuery('#' + dialogDiv + ' :input');
-		inputs.each(function() {
-			jQuery(this).appendTo(document.forms[formName]);
-	    });
-		document.forms[formName].submit();
+		appendDialogInputsToFormAndSubmit(dialogDiv, formName);
 	};
 	buttonList[cancelText] = function() {
 		if (resultField) {
@@ -345,6 +343,21 @@ function showConfirmationDialog(title, okText, cancelText, dialogDiv, formName,
 	});
 }
 
+/**
+ * Appends the input fields of a dialog back to the form and submits it.
+ * 
+ * @param dialogDiv ID of dialog div
+ * @param formName name of form
+ */
+function appendDialogInputsToFormAndSubmit(dialogDiv, formName) {
+	var inputs = jQuery('#' + dialogDiv + ' :input');
+	inputs.each(function() {
+		jQuery(this).addClass('hidden');
+		jQuery(this).appendTo(document.forms[formName]);
+    });
+	document.forms[formName].submit();
+}
+
 /**
  * Shows a simple confirmation dialog.
  * If the user presses Cancel then the current action is stopped (event.preventDefault()).
@@ -560,7 +573,7 @@ function checkPasswordStrength(fieldID, ajaxURL) {
 					"password": value
 			};
 			// make AJAX call
-			jQuery.post(ajaxURL + "?function=passwordStrengthCheck", {jsonInput: pwdJSON}, function(data) {checkPasswordStrengthHandleReply(data, fieldID);}, 'json');
+			jQuery.post(ajaxURL + "&function=passwordStrengthCheck", {jsonInput: pwdJSON}, function(data) {checkPasswordStrengthHandleReply(data, fieldID);}, 'json');
 		};
 	jQuery(field).keyup(check);
 }
@@ -615,3 +628,33 @@ function updateModulePositions(id, oldPos, newPos) {
 	}
 	jQuery('#' + id).val(positions.join(','));
 }
+
+/**
+ * Filters a select box by the value of the filter input field.
+ * 
+ * @param filterInput ID of input field for filter
+ * @param select ID of select box to filter
+ * @param event key event
+ */
+function filterSelect(filterInput, select, event) {
+	// if values were not yet saved, save them
+	if (!jQuery('#' + select).data('options')) {
+		var options = [];
+		jQuery('#' + select).find('option').each(function() {
+			options.push({value: $(this).val(), text: $(this).text()});
+		});
+		jQuery('#' + select).data('options', options);
+	}
+	// get matching values
+	var list = jQuery('#' + select).empty().scrollTop(0).data('options');
+	var search = jQuery.trim(jQuery('#' + filterInput).val());
+	var regex = new RegExp(search,'gi');
+	jQuery.each(list, function(i) {
+		var option = list[i];
+		if(option.text.match(regex) !== null) {
+			jQuery('#' + select).append(
+					jQuery('<option>').text(option.text).val(option.value)
+			);
+		}
+	});
+}
