@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: masscreate.php 5471 2014-10-25 19:17:53Z gruberroland $
+$Id: masscreate.php 5564 2015-05-15 19:16:46Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2013  Roland Gruber
+  Copyright (C) 2004 - 2015  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -60,6 +60,10 @@ if (!isLoggedIn()) {
 // Set correct language, codepages, ....
 setlanguage();
 
+if (!empty($_POST)) {
+	validateSecurityToken();
+}
+
 // show CSV if requested
 if (isset($_GET['getCSV'])) {
 	//download file
@@ -211,6 +215,7 @@ if (!empty($types)) {
 	$table->addElement(new htmlButton('submit', _('Ok')), true);
 }
 
+addSecurityTokenToMetaHTML($table);
 parseHtml(null, $table, array(), false, $tabindex, 'user');
 ?>
 <script type="text/javascript">
@@ -434,6 +439,7 @@ function showMainPage($scope, $selectedModules) {
 	}
 	$container->addElement($columnContainer, true);
 	
+	addSecurityTokenToMetaHTML($container);
 	$tabindex = 1;
 	parseHtml(null, $container, array(), false, $tabindex, $scope);
 	
