@@ -1,10 +1,10 @@
 <?php
 /*
-$Id: pdfpage.php 5206 2014-01-15 20:48:52Z gruberroland $
+$Id: pdfpage.php 5564 2015-05-15 19:16:46Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
-                2007 - 2014  Roland Gruber
+                2007 - 2015  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -55,6 +55,10 @@ checkIfToolIsActive('toolPDFEditor');
 
 setlanguage();
 
+if (!empty($_POST)) {
+	validateSecurityToken();
+}
+
 // check if user is logged in, if not go to login
 if (!$_SESSION['ldap'] || !$_SESSION['ldap']->server()) {
 	metaRefresh("../login.php");
@@ -643,6 +647,7 @@ $buttonContainer->addElement(new htmlHiddenInput('modules', $modules));
 $buttonContainer->addElement(new htmlHiddenInput('type', $_GET['type']));
 
 $container->addElement($buttonContainer, true);
+addSecurityTokenToMetaHTML($container);
 
 $tabindex = 1;
 parseHtml(null, $container, array(), false, $tabindex, $_GET['type']);
