@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: profilepage.php 5206 2014-01-15 20:48:52Z gruberroland $
+$Id: profilepage.php 5564 2015-05-15 19:16:46Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2014  Roland Gruber
+  Copyright (C) 2003 - 2015  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -51,6 +51,10 @@ checkIfToolIsActive('toolProfileEditor');
 
 setlanguage();
 
+if (!empty($_POST)) {
+	validateSecurityToken();
+}
+
 // check if user is logged in, if not go to login
 if (!$_SESSION['ldap'] || !$_SESSION['ldap']->server()) {
 	metaRefresh("../login.php");
@@ -169,7 +173,8 @@ elseif (isset($_GET['edit'])) {
 }
 
 // display formular
-echo ("<form action=\"profilepage.php?type=$type\" method=\"post\">\n");
+echo "<form action=\"profilepage.php?type=$type\" method=\"post\">\n";
+echo '<input type="hidden" name="' . getSecurityTokenName() . '" value="' . getSecurityTokenValue() . '">';
 
 $profName = '';
 if (isset($_GET['edit'])) {
